@@ -20,6 +20,8 @@
  *
  */
 
+#include <unistd.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <assert.h>
 #include <string.h>
@@ -30,7 +32,7 @@
 #include <usb.h>
 #include "hexfile.h"
 
-static const char rcsid[] = "$Id: fpga_load.c 6054 2009-03-01 14:19:27Z tzafrir $";
+static const char rcsid[] = "$Id: fpga_load.c 10548 2012-03-20 06:27:21Z tzafrir $";
 
 #define	ERR(fmt, arg...) do { \
 				if(verbose >= LOG_ERR) \
@@ -210,7 +212,7 @@ struct usb_device *dev_of_path(const char *path)
 		return NULL;
 	}
 	/* Find last '/' */
-	if((p = memrchr(path, '/', strlen(path))) == NULL) {
+	if((p = (const char *)memrchr(path, '/', strlen(path))) == NULL) {
 		ERR("Missing a '/' in %s\n", path);
 		return NULL;
 	}
@@ -221,7 +223,7 @@ struct usb_device *dev_of_path(const char *path)
 		return NULL;
 	}
 	/* Search for a '/' before that */
-	p = memrchr(path, '/', p - path);
+	p = (const char *)memrchr(path, '/', p - path);
 	if(p == NULL)
 		p = path;		/* Relative path */
 	else
@@ -555,7 +557,6 @@ int match_usb_device_identity(const struct usb_config_descriptor *config_desc,
 
 const struct astribank_type *my_usb_device_identify(const char devpath[], struct my_usb_device *mydev)
 {
-	struct usb_device_descriptor	*dev_desc;
 	struct usb_config_descriptor	*config_desc;
 	int				i;
 
@@ -568,7 +569,6 @@ const struct astribank_type *my_usb_device_identify(const char devpath[], struct
 		ERR("Bailing out\n");
 		return 0;
 	}
-	dev_desc = &mydev->dev->descriptor;
 	config_desc = mydev->dev->config;
 	for(i = 0; i < sizeof(astribank_types)/sizeof(astribank_types[0]); i++) {
 		if(match_usb_device_identity(config_desc, &astribank_types[i])) {
@@ -590,7 +590,6 @@ int my_usb_device_init(const char devpath[], struct my_usb_device *mydev, const
 	struct usb_interface		*interface;
 	struct usb_interface_descriptor	*iface_desc;
 	struct usb_endpoint_descriptor	*endpoint;
-	int				ret;
 	int				i;
 
 	assert(mydev != NULL);
@@ -636,10 +635,10 @@ int my_usb_device_init(const char devpath[], struct my_usb_device *mydev, const
 	mydev->abtype = abtype;
 	mydev->my_ep_in = abtype->my_ep_in;
 	mydev->my_ep_out = abtype->my_ep_out;
-	ret = get_usb_string(mydev->iManufacturer, BUFSIZ, dev_desc->iManufacturer, mydev->handle);
-	ret = get_usb_string(mydev->iProduct, BUFSIZ, dev_desc->iProduct, mydev->handle);
-	ret = get_usb_string(mydev->iSerialNumber, BUFSIZ, dev_desc->iSerialNumber, mydev->handle);
-	ret = get_usb_string(mydev->iInterface, BUFSIZ, iface_desc->iInterface, mydev->handle);
+	get_usb_string(mydev->iManufacturer, BUFSIZ, dev_desc->iManufacturer, mydev->handle);
+	get_usb_string(mydev->iProduct, BUFSIZ, dev_desc->iProduct, mydev->handle);
+	get_usb_string(mydev->iSerialNumber, BUFSIZ, dev_desc->iSerialNumber, mydev->handle);
+	get_usb_string(mydev->iInterface, BUFSIZ, iface_desc->iInterface, mydev->handle);
 	INFO("ID=%04X:%04X Manufacturer=[%s] Product=[%s] SerialNumber=[%s] Interface=[%s]\n",
 		dev_desc->idVendor,
 		dev_desc->idProduct,
